sphinx-asdf
===========

``sphinx-asdf`` is a plugin for `sphinx
<http://www.sphinx-doc.org/en/master/>`__ that enables generation of
documentation from `ASDF <https://asdf-standard.readthedocs.io/en/latest/>`__
schemas.

Installation
------------

The latest development version is available from the ``master`` branch `on
github <https://github.com/spacetelescope/sphinx-asdf>`__. To clone the
project:

::

    $ git clone https://github.com/spacetelescope/sphinx-asdf

To install:

::

    $ cd sphinx-asdf
    $ pip install .

To install in `development
mode <https://packaging.python.org/tutorials/distributing-packages/#working-in-development-mode>`__::

    $ pip install -e .


Contributing
------------

We welcome feedback and contributions to the project. Contributions of
code, documentation, or general feedback are all appreciated. Please
follow the `contributing guidelines <CONTRIBUTING.md>`__ to submit an
issue or a pull request.

We strive to provide a welcoming community to all of our users by
abiding to the `Code of Conduct <CODE_OF_CONDUCT.md>`__.
